==> kvirc_3.2.4.orig.tar.gz: kvirc-3.2.4/src/kvirc/module/kvi_mexlinkfilter.h <==
#ifndef _KVI_MEXLINKFILTER_H_
#define _KVI_MEXLINKFILTER_H_
//=============================================================================
//
//   File : kvi_mexlinkfilter.h
//   Creation date : Wed Apr 11 2003 03:07 by Szymon Stefanek
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 2003 Szymon Stefanek (pragma at kvirc dot net)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//=============================================================================

#include "kvi_settings.h"
#include "kvi_ircsocket.h"
#include "kvi_moduleextension.h"
#include "kvi_console.h"

class KviIrcLink;

// FIXME: this should filter KviIrcLink and not KviIrcSocket!

class KVIRC_API KviMexLinkFilter : public KviIrcSocket, public KviModuleExtension
{
	Q_OBJECT
public:
	KviMexLinkFilter(KviIrcLink * l,KviModuleExtensionDescriptor * d);
	~KviMexLinkFilter();
};

#endif //!_KVI_MEXLINKFILTER_H_

==> kvirc_3.4.0.orig.tar.gz: kvirc-3.4.0/src/kvirc/module/kvi_mexlinkfilter.h <==
#ifndef _KVI_MEXLINKFILTER_H_
#define _KVI_MEXLINKFILTER_H_
//=============================================================================
//
//   File : kvi_mexlinkfilter.h
//   Creation date : Wed Apr 11 2003 03:07 by Szymon Stefanek
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 2003-2006 Szymon Stefanek (pragma at kvirc dot net)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//=============================================================================

#include "kvi_settings.h"
#include "kvi_moduleextension.h"

#include <qobject.h>

class KviDataBuffer;

class KVIRC_API KviMexLinkFilter : public QObject, public KviModuleExtension
{
	Q_OBJECT
public:
	KviMexLinkFilter(KviModuleExtensionDescriptor * d);
	~KviMexLinkFilter();
public:
	virtual void processData(char * buffer,int len) = 0;
	virtual bool sendPacket(KviDataBuffer * pData) = 0;
};

#endif //!_KVI_MEXLINKFILTER_H_
